/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIESOR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.aries.application.management;

import java.io.IOException;
import java.io.InputStream;

import org.apache.aries.application.ApplicationMetadataFactory;

/**
 * A BundleConversion represents a .JAR file which has been converted in to 
 * an well-formed OSGi bundle, or a .WAR file which has been converted into a .WAB 
 * file
 */
public interface BundleConversion {

	/**
	 * @return The InputStream to the converted bundle.
	 */
	public InputStream getInputStream() throws IOException;
	
	/** 
	 * @param The ApplicationMetadataFactory used to parse the content of 
	 * the converted bundle into a BundleInfo object
	 * @return The bundle information for the converted bundle.
	 */
	public BundleInfo getBundleInfo(ApplicationMetadataFactory amf) throws IOException;
}
